NLSL: pidef Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
pidef Module Reference

## Variables
double precision, parameter | pi =3.1415926535897932384D0
double precision, parameter | radian =PI/180.0D0

## Variable Documentation

double precision, parameter pidef::pi =3.1415926535897932384D0

Definition at line 15 of file pidef.f90.

double precision, parameter pidef::radian =PI/180.0D0

Definition at line 15 of file pidef.f90.